@@ -13,7 +13,7 @@ def Inicializar(n):
   global DatosList,Orden,Estilo
   
   DatosList = [[sympy.pi,3.14]]
-  Orden = 8
+  Orden = n
   Documento = []
   return DatosList,Orden
   
